@@ -193,7 +193,10 @@
     Updated by      Richard Gooch   31-JUL-2001: Added support for DELETE
   event. Added debug trace to <action_modload>.
 
-    Last updated by Richard Gooch   8-AUG-2001: Added support for recursively
+    Updated by      Richard Gooch   8-AUG-2001: Added support for recursively
+  reading config directories.
+
+    Last updated by Richard Gooch   10-AUG-2001: Fixed support for recursively
   reading config directories.
 
 
@@ -671,7 +674,7 @@ static void read_config_file (CONST char *path, flag optional,
 	    char fname[STRING_LENGTH];
 
 	    if (de->d_name[0] == '.') continue;
-	    snprintf (fname, STRING_LENGTH, "%s/%s", path, de->d_name[0]);
+	    snprintf (fname, STRING_LENGTH, "%s/%s", path, de->d_name);
 	    read_config_file (fname, optional, event_mask);
 	}
 	closedir (dp);
